@@ -9,5 +9,5 @@ More information about PRAW can be found at https://github.com/praw-dev/praw.
 
 """
 
-from .const import __version__  # NOQA
-from .reddit import Reddit  # NOQA
+from .const import __version__
+from .reddit import Reddit
