@@ -1,20 +1,23 @@
 """Provide the SubmissionListingMixin class."""
-from typing import TYPE_CHECKING, Dict, Iterator, Union
+
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Iterator
 
 from ....const import API_PATH
 from ...base import PRAWBase
 from ..generator import ListingGenerator
 
 if TYPE_CHECKING:  # pragma: no cover
-    import praw
+    import praw.models
 
 
 class SubmissionListingMixin(PRAWBase):
     """Adds additional methods pertaining to :class:`.Submission` instances."""
 
     def duplicates(
-        self, **generator_kwargs: Union[str, int, Dict[str, str]]
-    ) -> Iterator["praw.models.Submission"]:
+        self, **generator_kwargs: str | int | dict[str, str]
+    ) -> Iterator[praw.models.Submission]:
         """Return a :class:`.ListingGenerator` for the submission's duplicates.
 
         Additional keyword arguments are passed in the initialization of
